==> nextcloud-app-bookmarks-1%3A14.2.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Copy link" : "Kopii ligilon",
    "Move" : "Movi",
    "Link copied to clipboard" : "Ligilo kopiita al tondujo",
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "Select all" : "Elekti ĉion",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
    "Go back" : "Reveni",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New" : "Nova",
    "New folder" : "Nova dosierujo",
    "Search" : "Serĉi",
    "Empty trash bin" : "Malpleni rubujon",
    "Enter a link" : "Entajpu ligilon",
    "Add a bookmark" : "Aldoni legosignon",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Rename folder" : "Alinomigi dosierujon",
    "Submit" : "Sendi",
    "Cancel" : "Nuligi",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
    "All bookmarks" : "Ĉiuj legosignoj",
    "Recent" : "Lastaj ŝanĝoj",
    "Shared with you" : "Kunhavata kun vi",
    "Files" : "Dosieroj",
    "Delete" : "Forigi",
    "Untagged" : "Sen etikedo",
    "Settings" : "Agordoj",
    "No bookmarks here" : "Neniu legosigno ĉi tie",
    "Client apps" : "Klientaj aplikaĵoj",
    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
    "Bookmarklet" : "Legosignilo",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Need help?" : "Ĉu necesas helpo?",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Root folder" : "Radika dosierujo",
    "Tags" : "Etikedoj",
    "Notes" : "Notoj",
    "Owner" : "Posedanto",
    "Sharing" : "Kunhavigo",
    "Select a user or group" : "Elektu uzanton aŭ grupon",
    "Share link" : "Kunhavigi ligilon",
    "Allow editing" : "Permesi modifon",
    "Allow resharing" : "Permesi rekunhavigon",
    "Link copied" : "Ligilo kopiita",
    "Privacy" : "Privateco",
    "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
    "Performance" : "Rendimento",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
    "Previews" : "Antaŭrigardoj",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Folder" : "Dosierujo",
    "Save" : "Konservi",
    "What's new?" : "Kio nova?",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A16.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Link copied to clipboard" : "Ligilo kopiita al tondujo",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Copy link" : "Kopii ligilon",
    "Move" : "Movi",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "Select all" : "Elekti ĉion",
    "Go back" : "Reveni",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New" : "Nova",
    "New folder" : "Nova dosierujo",
    "Search" : "Serĉi",
    "Empty trash bin" : "Malpleni rubujon",
    "Enter a link" : "Entajpu ligilon",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "Add a bookmark" : "Aldoni legosignon",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Rename folder" : "Alinomigi dosierujon",
    "Submit" : "Sendi",
    "Cancel" : "Nuligi",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
    "All bookmarks" : "Ĉiuj legosignoj",
    "Recent" : "Lastaj ŝanĝoj",
    "Shared with you" : "Kunhavata kun vi",
    "Files" : "Dosieroj",
    "Delete" : "Forigi",
    "Untagged" : "Sen etikedo",
    "No bookmarks here" : "Neniu legosigno ĉi tie",
    "Client apps" : "Klientaj aplikaĵoj",
    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
    "Bookmarklet" : "Legosignilo",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Need help?" : "Ĉu necesas helpo?",
    "Created on {date}" : "Kreita je {date}",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Root folder" : "Radika dosierujo",
    "Tags" : "Etikedoj",
    "Notes" : "Notoj",
    "Open file" : "Malfermi dosieron",
    "Link copied" : "Ligilo kopiita",
    "Owner" : "Posedanto",
    "Sharing" : "Kunhavigo",
    "Select a user or group" : "Elektu uzanton aŭ grupon",
    "Share link" : "Kunhavigi ligilon",
    "Allow editing" : "Permesi modifon",
    "Allow resharing" : "Permesi rekunhavigon",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "Privacy" : "Privateco",
    "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
    "Performance" : "Rendimento",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
    "Previews" : "Antaŭrigardoj",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Folder" : "Dosierujo",
    "Save" : "Konservi",
    "What's new?" : "Kio nova?",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to move parts of selection" : "Movo de partoj de la elekto malsukcesis",
    "Failed to delete parts of selection" : "Malsukceso forigi partojn de elekto",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");
